@@ -15,6 +15,9 @@ class TestStrings(unittest.TestCase):
         self.assertEqual(hs.collapse('a', 'b'), 'ab')
         self.assertEqual(hs.collapse('a', 'b', 'c'), 'abc')
 
+        self.assertEqual(hs.collapse('abc', surround="'"), "'a''b''c'")
+        self.assertEqual(hs.collapse('abc', surround="'", separate="-"), "'a'-'b'-'c'")
+
         self.assertEqual(hs.collapse('a', surround="'"), "'a'")
         self.assertEqual(hs.collapse('a', 'b', surround="'"), "'a''b'")
         self.assertEqual(hs.collapse('a', 'b', 'c', surround="'"), "'a''b''c'")
@@ -42,11 +45,16 @@ class TestStrings(unittest.TestCase):
 
         self.assertEqual(hs.collapse(['a'], separate=', ', surround="'"), "'a'")
         self.assertEqual(hs.collapse(['a', 'b'], separate=', ', surround="'"), "'a', 'b'")
-        self.assertEqual(hs.collapse(['a', 'b', 'c'], separate=', ', surround="'"), "'a', 'b', 'c'")
+        self.assertEqual(
+            hs.collapse(['a', 'b', 'c'], separate=', ', surround="'"),
+            "'a', 'b', 'c'"
+        )
 
     def test_format_number(self):
-        granularity_options = [hs.RoundTo.AUTO, hs.RoundTo.NONE, hs.RoundTo.THOUSANDS, hs.RoundTo.MILLIONS,
-                               hs.RoundTo.BILLIONS, hs.RoundTo.TRILLIONS]
+        granularity_options = [
+            hs.RoundTo.AUTO, hs.RoundTo.NONE, hs.RoundTo.THOUSANDS, hs.RoundTo.MILLIONS,
+            hs.RoundTo.BILLIONS, hs.RoundTo.TRILLIONS
+        ]
         places = [0, 1, 2, 3, 4, 5]
 
         parameter_combos = list(product(granularity_options, places))
@@ -101,11 +109,5 @@ class TestStrings(unittest.TestCase):
         results = [run_combinations_for_value(value) for value in test_values]
         results = pd.concat(results)
         results['granularity'] = results['granularity'].transform(lambda x: str(x))
-
-        expected_results = pd.read_csv(get_test_path('string/string__format_number__expected_values.csv'))
-
-        hv.assert_dataframes_match([results, expected_results])
-
-
-if __name__ == '__main__':
-    unittest.main()
+        expected_results = pd.read_csv(get_test_path('string/string__format_number__expected_values.csv'))  # noqa
+        self.assertTrue(hv.dataframes_match([results, expected_results]))
